Iterables
=========

.. toctree::

   reference_iterable_profile_discrete_grid
   reference_iterable_profile_noisy_discrete_grid
   reference_iterable_profile_ordinal_grid
   reference_iterable_profile_twelve_grid
   reference_iterable_simplex_grid
   reference_iterable_strategy_ordinal
   reference_iterable_strategy_threshold_grid
   reference_iterable_strategy_twelve
   reference_iterable_tau_vector_grid
